@@ -1,6 +1,6 @@
 from pathlib import Path
 
-__version__ = "1.1"
+__version__ = "1.1.2"
 
 LOGO = (Path(__file__).parent.absolute()/"logo.png").as_posix()
 DATAFILE = Path(__file__).parent.absolute()/"data/untouchable.dat"
@@ -14,7 +14,7 @@ INFO="""نگار قابلیت های زیر را داراست:
 * فاصله گذاری نادرست پرانتز ها نظیر ( نگار ) یا دیگر علایم را به صورت صحیح تنظیم می کند.
 * اعداد عربی مانند '١٢٣٤٥٦٧٨٩٠' و انگلیسی مانند '1234567890' را به معادل فارسی شان تبدیل می کند.
 * کاراکتر های غیر فارسی را شامل ',;%يةك' به معادل های فارسی شان تبدیل می کند.
-* کلماتی که با فاصله ی اشتباه به صورت ' می شود '، ' بی شک '، ' خانه اش ' و یا ' کمک تان ' نوشته شده‌، به صورت درست فاصله گذاری میشوند.
+* کلماتی که با فاصله ی اشتباه به صورت ' می شود '، ' بی شک '، ' خانه اش '، ' وظیفه شناس ' و یا ' کمک تان ' نوشته شده‌، به صورت درست فاصله گذاری میشوند.
 * کلماتی که به اشتباه بدون فاصله به صورت ' میشود '، ' بیشک ' , یا ' نمیرود ' نوشته شده‌، به صورت درست فاصله گذاری میشوند.
 * از استفاده ی بیش از یک علامت ؟؟؟؟ یا !!! جلوگیری می کند.
 * کلماتی که به صورت کشیـــــــــده نوشته شده اند را به صورت درست می نویسد.
